@@ -9,9 +9,9 @@ class DetectController:
         self.account = account
 
     @verify_credentials
-    def register_endpoint(self, name, tag=''):
+    def register_endpoint(self, name, tags):
         """ Register (or re-register) an endpoint to your account """
-        params = dict(id=name, tag=tag)
+        params = dict(id=name, tags=tags)
         res = requests.post(f'{self.account.hq}/account/endpoint', headers=self.account.headers, json=params)
         if res.status_code == 200:
             return res.text
@@ -43,11 +43,10 @@ class DetectController:
             raise Exception(res.text)
 
     @verify_credentials
-    def describe_activity(self, days=7, ident=None):
+    def describe_activity(self, days=7):
         """ Get report for an Account """
         params = dict(days=days)
-        route = f'/{ident}' if ident else ''
-        res = requests.get(f'{self.account.hq}/account/report{route}', headers=self.account.headers, params=params)
+        res = requests.get(f'{self.account.hq}/account/report', headers=self.account.headers, params=params)
         if res.status_code == 200:
             return res.json()
         raise Exception(res.text)
@@ -56,7 +55,7 @@ class DetectController:
     def export_report(self, days=7):
         """ Generate a redirect URL to a data dump """
         params = dict(days=days)
-        res = requests.get(f'{self.account.hq}/account/report-export', headers=self.account.headers, params=params)
+        res = requests.get(f'{self.account.hq}/account/report/export', headers=self.account.headers, params=params)
         if res.status_code == 200:
             return res.url
         raise Exception(res.text)
